#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""
from pocsuite.lib.request.requestspatch import requestsPatch

import pocsuite.thirdparty.requests as req

requestsPatch()
