#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Copyright (c) 2014-2015 pocsuite developers (http://seebug.org)
See the file 'docs/COPYING' for copying permission
"""

__title__ = 'pocsuite'
__version__ = '1.1.0'
__author__ = 'seebug.org'
__author_email__ = 's1@sebug.com'
__license__ = 'GPL 2.0'
__copyright__ = 'Copyright 2015 Knownsec'
